@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: profunctors
 version: 5.2
-id: profunctors-5.2-fef53ede72ba72080c6462b04bf9f01b
-key: profu_FMJAop937VgFDo4yT3F9MD
+id: profunctors-5.2-9a29145c6a42bab58852d072f6668ae3
+key: profu_2CmtYbnZzSI32wE7lp4LJt
 license: BSD3
 copyright: Copyright (C) 2011-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,13 +27,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/profunctors-5.2
-hs-libraries: HSprofunctors-5.2-FMJAop937VgFDo4yT3F9MD
+hs-libraries: HSprofunctors-5.2-2CmtYbnZzSI32wE7lp4LJt
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-orphans-0.5.0-a13c08e02979420be3bfcfc755842cf4
-    bifunctors-5.2-80b4a568e955c726356be64a7ae3918a
-    comonad-5-ef08fcd44c0efc29fa5bad32641dc22e
-    contravariant-1.4-db788d767efca0b89f051d890d0c132d
+    bifunctors-5.2-619b831167660978b6565dca15515574
+    comonad-5-e53ff69c5983127cf4f20e90dd6b5c9a
+    contravariant-1.4-9027be8359ae8a89877802024c295de2
     distributive-0.5.0.2-921805b919081e64e9b7d8c792bc35e0
     tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
